@@ -3,7 +3,7 @@
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
     2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
-    2017, 2018 Massachusetts Institute of Technology
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -39,24 +39,32 @@ USA.
 ;;; The HIGH range sequence is a u24 bytevector implementing an inversion list.
 
 (define-record-type <char-set>
-    (%make-char-set low high predicate)
+    (%make-char-set low high predicate table)
     char-set?
   (low %char-set-low)
   (high %char-set-high)
-  (predicate %char-set-predicate))
+  (predicate char-set-predicate)
+  ;; backwards compatibility for Edwin:
+  (table %char-set-table))
 
 (define (make-char-set low high)
-  (letrec
-      ((char-set
-	(%make-char-set low high
+  (letrec*
+      ((predicate
+	(lambda (char)
+	  (and (bitless-char? char)
+	       (char-in-set? char char-set))))
+       (char-set
+	(%make-char-set low high predicate
 	  (delay
-	    (let ((predicate
-		   (lambda (char)
-		     (and (bitless-char? char)
-			  (char-in-set? char char-set)))))
-	      (register-predicate! predicate 'char-set-predicate
-				   '<= bitless-char?)
-	      predicate)))))
+	    (let ((table (make-bytevector #x100)))
+	      (do ((cp 0 (fix:+ cp 1)))
+		  ((not (fix:< cp #x100)))
+		(bytevector-u8-set! table cp
+				    (if (%code-point-in-char-set? cp char-set)
+					1
+					0)))
+	      table)))))
+    (register-predicate! predicate 'char-set-predicate '<= bitless-char?)
     char-set))
 
 (define-integrable %low-cps-per-byte 8)
@@ -437,8 +445,8 @@ USA.
 		      (else #t)))
 	      #f)))))
 
-(define (char-set-predicate char-set)
-  (force (%char-set-predicate char-set)))
+(define (char-set-table char-set)
+  (force (%char-set-table char-set)))
 
 (define (char-set=? char-set . char-sets)
   (every (lambda (char-set*)
@@ -637,14 +645,6 @@ USA.
       (error:bad-range-argument end 'ascii-range->char-set))
   (char-set (cons start end)))
 
-(define (%char-set-table char-set)
-  (let ((table (make-bytevector #x100)))
-    (do ((cp 0 (fix:+ cp 1)))
-	((not (fix:< cp #x100)))
-      (bytevector-u8-set! table cp
-			  (if (%code-point-in-char-set? cp char-set) 1 0)))
-    table))
-
 (define (8-bit-char-set? char-set)
   (and (char-set? char-set)
        (let ((high (%char-set-high char-set)))
